<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Über </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spenden</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>Screenshot Tool</source>
        <translation>Schnappschuss-Werkzeug</translation>
    </message>
    <message>
        <source>License: </source>
        <translation>Lizenz: </translation>
    </message>
    <message>
        <source>Please use </source>
        <translation>Benutzen Sie bitte </translation>
    </message>
    <message>
        <source> to report bugs.</source>
        <translation> um Fehler zu melden.</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Bild für Wasserzeichen erforderlich</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation>Bitte fügen Sie ein Bild für das Wasserzeichen via Optionen &gt; Einstellungen &gt; Annotator &gt; Aktualisieren hinzu</translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Paint Item Shadows</source>
        <translation>Schatten unter gezeichneten Elementen anzeigen</translation>
    </message>
    <message>
        <source>When enabled, paint items cast shadows.</source>
        <translation>Wenn aktiviert, wird ein Schatten unter gezeichneten Elementen angezeigt.</translation>
    </message>
    <message>
        <source>Smooth Painter Paths</source>
        <translation>Glatte Malpfade</translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation>Wenn aktiviert, werden Stift und
Markerpfade nach dem fertigen Zeichnen geglättet.</translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation>Glättungsfaktor</translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation>Das Erhöhen des Glättungsfaktors wird die
Präzision für Stift und Marker verringern, aber
macht sie glatter.</translation>
    </message>
    <message>
        <source>Text Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <source>Sets the font for the Text Paint Item.</source>
        <translation>Legt die Schriftart für das Textelement fest.</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <source>Numbering Font</source>
        <translation>Schriftart für Nummern</translation>
    </message>
    <message>
        <source>Sets the font for the Numbering Paint Item.</source>
        <translation>Legt die Schriftart für die Nummerierung fest.</translation>
    </message>
    <message>
        <source>Watermark Image</source>
        <translation>Bild für Wasserzeichen</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation>Wasserzeichen drehen</translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation>Wenn aktiviert, dreht Wasserzeichen beim Einfügen um 45°</translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation>Beschriftungseinstellungen</translation>
    </message>
    <message>
        <source>Remember annotation tool selection and load on startup</source>
        <translation>Merke Auswahl des Beschriftungstool und stelle diese beim Starten wieder her</translation>
    </message>
    <message>
        <source>Switch to Select Tool after drawing Item</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation>Beim Starten Screenshot im Standardmodus aufnehmen</translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation>Anwendungsstil</translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation>Setzt den Anwendungsstil, welcher das Aussehen des GUIs definiert.
Eine Änderung benötigt einen Neustart von ksnip, um wirksam zu werden.</translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation>Anwendungseinstellungen</translation>
    </message>
    <message>
        <source>Use Tray Icon</source>
        <translation>Tray Icon verwenden</translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation>Bei Aktivierung wird ein Tray Icon in der Taskbar hinzugefügt, sofern das Betriebssystem dies unterstützt.
Diese Änderung erfordert einen Neustart.</translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation>Zum Tray minimieren</translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation>Zum Tray schließen</translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation>Neue Aufnahmen automatisch in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Auto Hide Tabs</source>
        <translation>Tabs automatisch ausblenden</translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation>Tabs verwenden</translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation>Änderung erfordert Neustart.</translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation>Nur eine Instanz von ksnip starten</translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation>Im Tray minimiert starten</translation>
    </message>
    <message>
        <source>Hide Tabbar when only one Tab is used.</source>
        <translation>Tableiste verstecken wenn nur ein Tab offen ist.</translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass its
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation>Mit dieser Option wird das Ausführen von nur einer ksnip-Instanz erlaubt,
alle weiteren Instanzen werden ihre Argumente an die zuerst gestartete
Instanz übergeben und sich wieder schließen. Eine Änderung dieser
Einstellung erfordert einen Neustartet aller Instanzen.</translation>
    </message>
    <message>
        <source>Remember Main Window position on move and load on startup</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>The Author:</source>
        <translation>Der Autor:</translation>
    </message>
    <message>
        <source>Contributors:</source>
        <translation>Mitwirkenden:</translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation>Spanische Übersetzung</translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation>Niederländische Übersetzung</translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation>Russische Übersetzung</translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation>Norwegische Übersetzung</translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation>Französische Übersetzung</translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation>Polnische Übersetzung</translation>
    </message>
    <message>
        <source>Snap &amp; Flatpak Support</source>
        <translation>Snap- und Flatpak-Support</translation>
    </message>
    <message>
        <source>Feature Implementation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation>Warnung - </translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation>Die Bildschirmaufnahme %1%2%3 wurde verändert.
Speichern?</translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>Rectangular Area</source>
        <translation>Rechteckiger Bereich</translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation>Zeichnen Sie einen rechteckigen Bereich mit der Maus</translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation>Vollbild (alle Monitore)</translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation>Vollbild Aufnahme einschließlich aller Monitore</translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation>Aktueller Bildschirm</translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation>Aufnahme des Bildschirms auf dem sich dezeit die Maus befindet</translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation>Aktives Fenster</translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation>Aufnahme des aktiven Fensters</translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation>Fenster unter der Maus</translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation>Aufnahme des Fensters unter der Maus</translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation>Letzter Rechteckiger Bereich</translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation>Einen Screenshot des zuletzt ausgewählten rechteckigen Bereichs aufnehmen</translation>
    </message>
    <message>
        <source>Screenshot Portal</source>
        <translation>Screenshot-Portal</translation>
    </message>
    <message>
        <source>Uses the screenshot Portal for taking screenshot</source>
        <translation>Verwendet Screenshot Portal um Bildschirmaufnahmen zu erstellen</translation>
    </message>
</context>
<context>
    <name>DeleteImageOperation</name>
    <message>
        <source>Delete Image</source>
        <translation>Bild löschen</translation>
    </message>
    <message>
        <source>The item &apos;%1&apos; will be deleted.
Do you want to continue?</source>
        <translation>Das Objekt &apos;%1&apos; wird gelöscht.
Wollen Sie Fortfahren?</translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>here</source>
        <translation>hier</translation>
    </message>
    <message>
        <source>Also possible, </source>
        <translation>Auch möglich, </translation>
    </message>
    <message>
        <source>Donations are always welcome</source>
        <translation>Spenden sind immer willkommen</translation>
    </message>
    <message>
        <source>Donation</source>
        <translation>Spende</translation>
    </message>
    <message>
        <source>Become a GitHub Sponsor</source>
        <translation>GitHub Sponsor werden</translation>
    </message>
    <message>
        <source>ksnip is a non-profitable copylefted libre software project, and&lt;br/&gt;still has some costs that need to be covered,&lt;br/&gt;like domain costs or hardware costs for cross-platform support.</source>
        <translation>ksnip ist ein unkommerzielles, freies und unter „Copyleft“ stehendes Softwareprojekt, &lt;br/&gt;für das jedoch Kosten anfallen, die es zu decken gilt,&lt;br/&gt; wie z.B. Kosten für die Internetdomäne oder Hardwarekosten für die plattformübergreifende Unterstützung.</translation>
    </message>
    <message>
        <source>If you want to help or just&lt;br/&gt;want to appreciate the work being done&lt;br/&gt;by treating developers to a beer or coffee, you can do that</source>
        <translation>Falls du helfen möchtest oder &lt;br/&gt;deine Wertschätzung für die Arbeit ausdrücken möchtest&lt;br/&gt;, indem du den Entwicklern ein Bier oder Kaffee ausgeben möchtest, kannst du das gerne tun</translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation>Erfolgreich hochgeladen</translation>
    </message>
    <message>
        <source>Upload script </source>
        <translation>Script hochladen </translation>
    </message>
    <message>
        <source> finished successfully.</source>
        <translation> erfolgreich abgeschlossen.</translation>
    </message>
    <message>
        <source>Uploaded to</source>
        <translation type="unfinished">Hochgeladen zu</translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation>Temporäres Bild kann nicht zum Hochladen gespeichert werden.</translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation>Starten des Prozesses nicht möglich, prüfen Sie Pfad und Berechtigungen.</translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation>Prozess abgestürzt</translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation>Der Prozess hat ein Timeout erreicht.</translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation>Prozesslesefehler.</translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation>Prozessschreibfehler.</translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation>Web-Fehler, Konsolenausgabe prüfen.</translation>
    </message>
    <message>
        <source>Unknown process error.</source>
        <translation>Unbekannter Prozess-Fehler.</translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation>Hochladen fehlgeschlagen</translation>
    </message>
    <message>
        <source>Script wrote to StdErr.</source>
        <translation>Script hat in die Fehlerausgabe (StdErr) geschrieben.</translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation>Systemweite Tastenkürzel aktivieren</translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation>Rechteckigen Bereich aufnehmen</translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation>Gesamten Bildschirm aufnehmen</translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation>Aktuellen Bildschirm aufnehmen</translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation>Aktives Fenster aufnehmen</translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation>Fenster unter Mauszeiger aufnehmen</translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation>Systemweite Tastenkürzel</translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11</source>
        <translation>Tastenkürzel werden nur unter Windows und X11 unterstützt</translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation>Letzten rechteckigen Bereich aufnehmen</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Capture using Portal</source>
        <translation>Aufnahme über Portal</translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation>Mauszeiger auf Screenshot aufnehmen</translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation>Legt fest, ob der Mauszeiger auf
Screenshots sichtbar sein soll.</translation>
    </message>
    <message>
        <source>Freeze Image while snipping</source>
        <translation>Bild während der Aufnahme einfrieren</translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation>Lupe im Ausschnittsbereich anzeigen</translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation>Zeigt eine Lupe an, welche in das Hintergrundbild
hineinzoomt. Diese Option funktioniert nur, wenn
„Bild während der Aufnahme einfrieren“ aktiviert wurde.</translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation>Lineale bei der Auswahl des rechteckigen Bereichs anzeigen</translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation>Horizontale und vertikale Linien vom
Bildschirmrand zum Mauszeiger anzeigen.</translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation>Position und Größe des Ausschnittsbereichs anzeigen</translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation>Ausschnittsbereich Mauszeigerfarbe</translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation>Ausschnittsbereich Mauszeigerstärke</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation type="unfinished">Bildgrabber</translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is shown and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation>Ist diese Option gesetzt, wird der Hintergrund
eingefroren und eine rechteckige Auswahl kann
getroffen werden. Sie wirkt sicht auch auf verzögerte
Screenshots aus; aktiviert, passiert die Verzögerung
bevor die Auswahl getroffen werden kann; deaktviert,
geschieht die Verzögerung, nachdem die Auswahl
getroffen wurde. Diese Option ist unter Wayland stets
deaktiviert, unter macOS stets aktiviert.</translation>
    </message>
    <message>
        <source>When left mouse button is not pressed the position
is shown, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation>Wenn der Mauszeiger nicht gedrückt wird, wird die
Position angezeigt; wenn der Mauszeiger gedrückt wird,
wird die größe des markierten Bereichs links und oberhalb
des Ausschnittsbereichs angezeigt.</translation>
    </message>
    <message>
        <source>Force Generic Wayland Screenshot</source>
        <translation>Erzwinge Screenshot über eine standardmäßige Wayland-Funktion</translation>
    </message>
    <message>
        <source>Scale Generic Wayland Screenshots</source>
        <translation>Skaliere Screenshots über eine standardmäßige Wayland-Funktion</translation>
    </message>
    <message>
        <source>Generic Wayland implementations that use
XDG-DESKTOP-PORTAL handle screen scaling
differently. Enabling this option will
determine the current screen scaling and
apply that to the screenshot in ksnip.</source>
        <translation>Standardmäßige Wayland-Implementationen, die
XDG-DESKTOP-PORTAL verwenden, handhaben
die Bildschirmskalierung unterschiedlich. Wird diese
Option aktiviert, wird die aktuelle Bildschirmskalierung
ermittelt und auf den Screenshot in ksnip angewendet.</translation>
    </message>
    <message>
        <source>GNOME and KDE Plasma support their own Wayland
and the Generic XDG-DESKTOP-PORTAL screenshots.
Enabling this option will force KDE Plasma and
GNOME to use the XDG-DESKTOP-PORTAL screenshots.
Change in this option require a ksnip restart.</source>
        <translation>GNOME und KDE Plasma unterstützen sowohl eigene Wayland- als
auch die standardmäßigen XDG-DESKTOP-PORTAL-Screenshots.
Wird diese Option aktiviert, werden KDE Plasma und GNOME gezwungen,
XDG-DESKTOP-PORTAL-Screenshots zu verwenden. Eine Änderung
dieser Option erfordert einen Neustart von ksnip.</translation>
    </message>
    <message>
        <source>Show Main Window after capturing screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Main Window after capturing a new screenshot
when the Main Window was hidden or minimized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow resizing rect area selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will, after selecting a rect
area, allow resizing the selection. When
done resizing the selection can be confirmed
by pressing return.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window during screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Main Window when capturing a new screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the color of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area cursor.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation>Imgur-Verlauf</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation>Zeitstempel</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>Löschlink</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation>Hochladen zu imgur.com abgeschlossen!</translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation>Neues Token erhalten, versuche erneut hochzuladen …</translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation>Das Imgur-Token ist abgelaufen, fordere neues Token an …</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation>Anonymen Upload erzwingen</translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation>Imgur-Link immer in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation>Client-ID</translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation>Client-Geheimnis</translation>
    </message>
    <message>
        <source>PIN</source>
        <translation>PIN</translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation>Imgur-PIN eingeben, die gegen ein Token ausgetauscht wird.</translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation>PIN anfordern</translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation>Token anfordern</translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation>Imgur-Verlauf</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur-Hochlader</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation>Warte auf imgur.com …</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation>Imgur-Token wurde erfolgreich aktualisiert.</translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation>Fehler beim Aktualisieren des Imgur-Tokens.</translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation>Nach dem Hochladen Imgur-Link im Standardbrowser öffnen</translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation>Direkt zum Bild verlinken</translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation>Basis-URL:</translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation>Basis-URL, die für Kommunikation mit Imgur verwendet wird.
Änderung erfordert Neustart.</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation>Zeitverzögerung in Sekunden zwischen dem Auslösen
und der Aufnahme des Bildschirmfotos.</translation>
    </message>
    <message>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation>Bildschirmaufnahme im Dateisystem speichern</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation>Bildschirmaufnahme in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Werkzeuge</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Zuschneiden</translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation>Bildschirmaufnahme zuschneiden</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unsaved</source>
        <translation>Ungespeichert</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Hochladen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation>Druckdialog öffnen</translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation>Druckvorschau</translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation>Druckvorschau öffnen</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>Skalieren</translation>
    </message>
    <message>
        <source>Scale Screen Capture</source>
        <translation>Bildschirmaufnahme skalieren</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Optionen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp)</source>
        <translation>Bilddateien (* .png * .jpg * .bmp)</translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation>Wasserzeichen hinzufügen</translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation>Fügt dem aufgenommenem Bild ein Wasserzeichen hinzu. Mehrere Wasserzeichen können hinzugefügt werden.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>Unable to show image</source>
        <translation>Bild kann nicht angezeigt werden</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Speichern als…</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation>Eingebettet einfügen</translation>
    </message>
    <message>
        <source>Upload capture to external source</source>
        <translation>Lade die Aufnahme auf eine externe Quelle hoch</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Anheften</translation>
    </message>
    <message>
        <source>Pin screenshot to foreground in frameless window</source>
        <translation>Hefte Screenshot am Vordergrund in einem rahmenlosen Fenster an</translation>
    </message>
    <message>
        <source>No image provided but one was expected.</source>
        <translation>Kein Bild geliefert, obwohl eines erwartet wurde.</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation type="unfinished">Pfad kopieren</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Verzeichnis öffnen</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Anzeigen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MultiCaptureHandler</name>
    <message>
        <source>Save</source>
        <translation type="unfinished">Speichern</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation type="unfinished">Speichern als</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Verzeichnis öffnen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">Kopieren</translation>
    </message>
    <message>
        <source>Copy Path</source>
        <translation>Pfad kopieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation>Aufnahme</translation>
    </message>
</context>
<context>
    <name>PinWindow</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Schließen</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Andere schließen</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Alles schließen</translation>
    </message>
</context>
<context>
    <name>PinWindowHandler</name>
    <message>
        <source>Pin Window %1</source>
        <translation>Hefte Fenster %1 an</translation>
    </message>
</context>
<context>
    <name>RenameOperation</name>
    <message>
        <source>Image Renamed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Successfully renamed image to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Rename Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to rename image to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New filename:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation>Speichern als</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Alle Dateien</translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation>Bild gespeichert</translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation>Speichern des Bildes fehlgeschlagen</translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation>Gespeichert unter</translation>
    </message>
    <message>
        <source>Failed to save image to</source>
        <translation>Speicherung fehlgeschlagen unter</translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation>Neue Aufnahmen automatisch im Standardverzeichnis speichern</translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation type="unfinished">Aufforderung zum Speichern, bevor nicht gespeicherte Änderungen verworfen werden</translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation>Zuletzt verwendeten Speicherort merken</translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation>Ist diese Option gesetzt, wird das in den Einstellungen gesetzte Verzeichnis zum Abspeichern
bei jedem Speichern ignoriert und durch das zuletzt benutzte Speicherverzeichnis ersetzt.</translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation type="unfinished">Speicherort und Dateiname für Aufnahmen</translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation>Unterstützte Formate sind JPG, PNG und BMP. Wenn kein Format angegeben wird, wird standardmäßig PNG benutzt.
Dateinamen können die folgenden Platzhalter verwenden:
-$Y, $M, $D für das Datum, $h, $m, $s für die Uhrzeit, oder $T für die Zeit im Format hhmmss.
- mehrere aufeinanderfolgende # als Zähler. #### ergibt 0001, der darauffolgende Screenshot wäre 0002.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Durchsuchen</translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation>Speichereinstellungen</translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation type="unfinished">Speicherort für Aufnahmen</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Factor</source>
        <translation>Faktor</translation>
    </message>
    <message>
        <source>Save Quality</source>
        <translation>Speicherqualität</translation>
    </message>
    <message>
        <source>Specify 0 to obtain small compressed files, 100 for large uncompressed files.
Not all image formats support the full range, JPEG does.</source>
        <translation>0 angeben, um kleine komprimierte Dateien zu erhalten, 100 für große unkomprimierte Dateien.
Nicht alle Bildformate unterstützen die gesamte Bandbreite, JPEG schon.</translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation>Skriptausgabe in Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Script:</source>
        <translation>Skript:</translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation>Pfad zum Script, das zum Upload aufgerufen wird. Beim Upload wird der Pfad zur temporären
png-Datei als einziges Argument an das Script übergeben.</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished">Durchsuchen</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Skriptbasierter Upload</translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation>Upload-Skript auswählen</translation>
    </message>
    <message>
        <source>Stop when upload script writes to StdErr</source>
        <translation>Stopp das Skript, wenn es in die Standardfehlerausgabe (StdErr) schreibt</translation>
    </message>
    <message>
        <source>Marks the upload as failed when script writes to StdErr.
Without this setting errors in the script will be unnoticed.</source>
        <translation>Markiert den Upload als fehlgeschlagen, wenn das Skript in die Standardfehlerausgabe (StdErr) schreibt.
Ohne diese Einstellung werden Fehler im Skript möglicherweise nicht bemerkt.</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>RegEx Expression. Only copy to clipboard what matches the RegEx Expression.
When omitted, everything is copied.</source>
        <translation>Reguläre Ausdrücke. Nur das in die Zwischenablage kopieren, was dem regulären Ausdruck entspricht.
Alles wird kopiert wenn leer.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation>Bildgrabber</translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation>Imgur-Uploader</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Anwendung</translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation>Annotator</translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Uploader</translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation>Skriptbasierter Upload</translation>
    </message>
    <message>
        <source>Saver</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation>Aufkleber</translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation>Hoch</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Runter</translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation>Standard-Aufkleber nutzen</translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation>Aufkleber-Einstellungen</translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation>Vektorgrafik-Dateien (*.svg)</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Add Stickers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation>Editor Anzeigen</translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation>Bild auswählen</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Alle Dateien</translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation>Upload-Skript erforderlich</translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation>Bitte füge ein Upload-Skript über Optionen &gt; Einstellungen &gt; Upload-Skript hinzu</translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation>Aufnahme hochladen</translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation>Du bist dabei das Bild zu einem externen Ziel hochzuladen, möchtest Du fortfahren?</translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation type="unfinished">Vor dem Hochladen nach Bestätigung fragen</translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation>Upload-Typ:</translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <source>Script</source>
        <translation>Skript</translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation>Uploader</translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Build</source>
        <translation>Build</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation type="unfinished">Verwendet:</translation>
    </message>
</context>
</TS>
